# Bigraph-Viz
A graphviz-based plotting tool for compositional bigraph schema

## Getting Started

Bigraph-Viz is available on PyPI [here](https://pypi.org/project/bigraph-viz/0.0.1/), and can be installed as a python library like this:

```console
$ pip install bigraph-viz
```

This requires [graphviz](https://pypi.org/project/graphviz/)
